@@ -27,18 +27,18 @@ public interface DaemonContext
 
     /**
      * @return  A {@link DaemonController} object that can be used to control
-     *          the {@link Daemon} instance that this <code>DaemonContext</code>
+     *          the {@link Daemon} instance that this {@code DaemonContext}
      *          is passed to.
      */
-    public DaemonController getController();
+    DaemonController getController();
 
     /**
      * @return An array of {@link String} arguments supplied by the environment
      *         corresponding to the array of arguments given in the
-     *         <code>public static void main()</code> method used as an entry
+     *         {@code public static void main()} method used as an entry
      *         point to most other java programs.
      */
-    public String[] getArguments();
+    String[] getArguments();
 
 }
 
